@@ -150,7 +150,21 @@ public:
 
 
 
+struct SparseFM {
+    // SparseFM();
+    // SparseFM( struct  fm_env_sparse* penv);
 
+    int n;
+
+    vector<double>  m_singletons;
+    vector<double>  m_pairs;
+    vector<double>  m_tuples;
+
+    vector<int> m_pair_index;// goes in pairs, hence  m_pair_index[2i],m_pair_index[2i+1] corresponds to m_pairs[i];
+    vector<int> m_tuple_start; // pints to cardinality, list of elements, stored  in m_tuple_content
+    vector<int> m_tuple_content;  // for any j such that m_tules[j] is the value, m_tuple_content[m_tuple_start[j]] is the cardinality
+};
+/*
 struct SparseFM {
 	int n;
 
@@ -162,7 +176,8 @@ struct SparseFM {
 
 	vector<int> m_tuple_start; // pints to cardinality, list of elements, stored  in m_tuple_content
 	vector<int> m_tuple_content;  // for any j such that m_tules[j] is the value, m_tuple_content[m_tuple_start[j]] is the cardinality
-};	
+};
+*/	
 #else
 struct SparseFM {
 	int n;
