@@ -24,7 +24,114 @@ This file can also be imported as a module and contains the following
 functions:
     * fm_init - initializes the package and returns env
     * fm_free - frees env
-    * to be continued
+    * ShowCoalitions
+    * generate_fm_2additive_concave
+    * ShowCoalitionsCard
+    * generate_fmconvex_tsort
+    * generate_fm_tsort
+    * ConvertCard2Bit
+    * IsMeasureSupermodular
+    * IsMeasureAdditive
+    * export_maximal_chains
+    * Choquet
+    * Sugeno
+    * ExpandKinteractive2Bit
+    * ExpandKinteractive2Bit_m
+    * py_Shapley
+	* Banzhaf
+	* ShapleyMob
+	* BanzhafMob
+	* ConstructLambdaMeasure
+	* ConstructLambdaMeasureMob
+	* dualm(double
+	* dualmMob(double
+	* FuzzyMeasureFit
+	* FuzzyMeasureFitMob
+	* FuzzyMeasureFitKtolerant
+	* FuzzyMeasureFitLPKmaxitive
+	* FuzzyMeasureFitLPKinteractive
+	* FuzzyMeasureFitLPKinteractiveMaxChains
+	* FuzzyMeasureFitLPKinteractiveAutoK
+	* FuzzyMeasureFitLPKinteractiveMarginal
+	* FuzzyMeasureFitLPKinteractiveMarginalMaxChain
+	* FuzzyMeasureFitLP
+	* FuzzyMeasureFitLPMob
+	* fittingOWA
+	* fittingWAM
+	* Interaction
+	* InteractionB
+	* InteractionMob
+	* InteractionBMob
+	* BipartitionShapleyIndex
+	* BipartitionBanzhafIndex
+	* BNonadditivityIndexMob
+	* NonadditivityIndex
+	* NonmodularityIndex
+	* NonmodularityIndexMob
+	* NonmodularityIndexKinteractive
+	* NonmodularityIndexMobkadditive
+	* Mobius
+	* Zeta
+	* dualMobKadd
+	* Shapley2addMob
+	* Banzhaf2addMob
+	* prepare_fm_sparse
+	* ShapleyMob_sparse
+	* BanzhafMob_sparse
+	* populate_fm_2add_sparse
+	* add_pair_sparse
+	* add_tuple_sparse
+	* populate_fm_2add_sparse_from2add
+	* expand_2add_full
+	* expand_sparse_full
+	* sparse_get_singletons
+	* Nonmodularityindex_sparse
+	* SizeArraykinteractive
+	* IsSubsetC
+	* IsElementC
+	* IsMeasureBalanced
+	* IsMeasureSelfdual
+	* IsMeasureSubadditive
+	* IsMeasureSubmodular
+	* IsMeasureSuperadditive
+	* IsMeasureSymmetric
+	* IsMeasureKMaxitive
+	* IsMeasureAdditiveMob
+	* IsMeasureBalancedMob
+	* IsMeasureSelfdualMob
+	* IsMeasureSubadditiveMob
+	* IsMeasureSubmodularMob
+	* IsMeasureSuperadditiveMob
+	* IsMeasureSupermodularMob
+	* IsMeasureSymmetricMob
+	* IsMeasureKMaxitiveMob
+	* fm_arraysize
+	* generate_fm_minplus
+	* generate_fm_2additive_convex
+	* generate_fm_2additive_convex_withsomeindependent
+	* tuple_cardinality_sparse
+	* get_num_tuples(struct
+	* get_sizearray_tuples(struct
+	* is_inset_sparse
+	* is_subset_sparse
+	* sparse_get_pairs
+	* sparse_get_tuples
+	* generate_fm_2additive_convex_sparse
+	* generate_fm_kadditive_convex_sparse
+	* min_subset
+	* max_subset
+	* min_subsetC
+	* max_subsetNegC
+	* ChoquetKinter
+	* ChoquetMob
+	* Entropy
+	* Orness
+	* OWA
+	* WAM
+	* Choquet2addMob
+	* min_subset_sparse
+	* max_subset_sparse
+	* ChoquetMob_sparse
 """
 
 
